@@ -1742,9 +1742,6 @@ class VariableClUpdateNewBinhost(Variable):
             binhost = self.Get('cl_update_binhost_choice')
             if binhost == 'auto':
                 return self.Get('cl_update_binhost')
-            elif not binhost.startswith('https://') and not binhost.startswith('ftp://') and not binhost.startswith(
-                    'http://'):
-                binhost = f"https://{binhost}"
             return binhost
         return self.Get('cl_update_binhost')
 
